[MPlayer-cvslog] r24581 - trunk/libaf/af_format.c

reimar subversion at mplayerhq.hu
Wed Sep 19 17:44:09 CEST 2007


Author: reimar
Date: Wed Sep 19 17:44:09 2007
New Revision: 24581

Log:
Fix loads of typos


Modified:
   trunk/libaf/af_format.c

Modified: trunk/libaf/af_format.c
==============================================================================
--- trunk/libaf/af_format.c	(original)
+++ trunk/libaf/af_format.c	Wed Sep 19 17:44:09 2007
@@ -28,14 +28,14 @@ long int lrintf(float);
 /* Functions used by play to convert the input audio to the correct
    format */
 
-/* The below includes retrives functions for converting to and from
+/* The below includes retrieves functions for converting to and from
    ulaw and alaw */ 
 #include "af_format_ulaw.c"
 #include "af_format_alaw.c"
 
-// Switch endianess
+// Switch endianness
 static void endian(void* in, void* out, int len, int bps);
-// From singed to unsigned and the other way
+// From signed to unsigned and the other way
 static void si2us(void* data, int len, int bps);
 // Change the number of bits per sample
 static void change_bps(void* in, void* out, int len, int inbps, int outbps);
@@ -110,11 +110,11 @@ static int control(struct af_instance_s*
     
     af->play = play; // set default
     
     // look whether only endianess differences are there
     if ((af->data->format & ~AF_FORMAT_END_MASK) ==
 	(data->format & ~AF_FORMAT_END_MASK))
     {
-	af_msg(AF_MSG_VERBOSE,"[format] Accelerated endianess conversion only\n");
+	af_msg(AF_MSG_VERBOSE,"[format] Accelerated endianness conversion only\n");
 	af->play = play_swapendian;
     }
     if ((data->format == AF_FORMAT_FLOAT_NE) &&
@@ -146,7 +146,7 @@ static int control(struct af_instance_s*
     return AF_OK;
   }
   case AF_CONTROL_FORMAT_FMT | AF_CONTROL_SET:{
-    // Check for errors in configuraton
+    // Check for errors in configuration
     if(AF_OK != check_format(*(int*)arg))
       return AF_ERROR;
 
@@ -172,7 +172,7 @@ static af_data_t* play_swapendian(struct
 {
   af_data_t*   l   = af->data;	// Local data
   af_data_t*   c   = data;	// Current working data
-  int 	       len = c->len/c->bps; // Lenght in samples of current audio block
+  int 	       len = c->len/c->bps; // Length in samples of current audio block
 
   if(AF_OK != RESIZE_LOCAL_BUFFER(af,data))
     return NULL;
@@ -189,7 +189,7 @@ static af_data_t* play_float_s16(struct 
 {
   af_data_t*   l   = af->data;	// Local data
   af_data_t*   c   = data;	// Current working data
-  int 	       len = c->len/4; // Lenght in samples of current audio block
+  int 	       len = c->len/4; // Length in samples of current audio block
 
   if(AF_OK != RESIZE_LOCAL_BUFFER(af,data))
     return NULL;
@@ -208,7 +208,7 @@ static af_data_t* play_s16_float(struct 
 {
   af_data_t*   l   = af->data;	// Local data
   af_data_t*   c   = data;	// Current working data
-  int 	       len = c->len/2; // Lenght in samples of current audio block
+  int 	       len = c->len/2; // Length in samples of current audio block
 
   if(AF_OK != RESIZE_LOCAL_BUFFER(af,data))
     return NULL;
@@ -228,7 +228,7 @@ static af_data_t* play(struct af_instanc
 {
   af_data_t*   l   = af->data;	// Local data
   af_data_t*   c   = data;	// Current working data
-  int 	       len = c->len/c->bps; // Lenght in samples of current audio block
+  int 	       len = c->len/c->bps; // Length in samples of current audio block
 
   if(AF_OK != RESIZE_LOCAL_BUFFER(af,data))
     return NULL;
@@ -292,7 +292,7 @@ static af_data_t* play(struct af_instanc
     }
   }
 
   // Switch from cpu native endian to the correct endianess 
   if((l->format&AF_FORMAT_END_MASK)!=AF_FORMAT_NE)
     endian(l->audio,l->audio,len,l->bps);
 
@@ -110,11 +110,11 @@ static int control(struct af_instance_s*
     af->play = play; // set default
     
-    // look whether only endianess differences are there
+    // look whether only endianness differences are there
     if ((af->data->format & ~AF_FORMAT_END_MASK) ==
 	(data->format & ~AF_FORMAT_END_MASK))
@@ -292,7 +292,7 @@ static af_data_t* play(struct af_instanc
   }
 
-  // Switch from cpu native endian to the correct endianess 
+  // Switch from cpu native endian to the correct endianness 
   if((l->format&AF_FORMAT_END_MASK)!=AF_FORMAT_NE)
     endian(l->audio,l->audio,len,l->bps);



More information about the MPlayer-cvslog mailing list